### Начало работы

PDFMathTranslate — это мощный инструмент для перевода PDF. Вы можете установить и начать использовать этот инструмент различными способами.

---

### Установка

1. [**Windows EXE**](./УСТАНОВКА_winexe.md) <small>Рекомендуется для Windows</small>  
2. [**Docker**](./УСТАНОВКА_docker.md) <small>Рекомендуется для Linux</small>  
3. [**uv** (менеджер пакетов Python)](./УСТАНОВКА_uv.md) <small>Рекомендуется для macOS</small>

---

### Использование

1. [Использование **WebUI**](./USAGE_webui.md)  
2. [Использование **плагина Zotero**](https://github.com/guaguastandup/zotero-pdf2zh) (Сторонняя программа)  
3. [Использование **командной строки**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>